# Image-Perception-and-OCR

# 图像感知与内容识别

https://pypi.org/project/fmcimage/

A lightweight python package that contains necessary modules for perceiving images and using ocr.

Utilizes mainly opencv and tesseract.

It does not necessarily work in OS other than Windows 11.

一个轻量级的Python包，包含了感知图像和使用OCR所需的必要模块，

主要利用了opencv和tesseract，

在除了 windows 11 以外的操作系统不一定可用。

> Note:
> This is a lightweight, even an ad hoc python package that may not be taylored for general use. I'm also pretty sure there is an abundant collection of repos that have similar implementations in the English world. Therefore I'll be concise in the project description and will not provide English version.

> 这是一个轻量级、可以说是专为我自己开发的Python包，可能不适合一般用途。我也相信在英语世界中存在大量类似实现的仓库。因此，我会简略转写项目介绍，并且不提供英文版本。
